@@ -458,7 +458,9 @@ def key_handler(key_name):
 		elif (cur_button == 1):
 			runaway()
 			return 0
-		elif (cur_button == 2): useitem()
+		elif (cur_button == 2):
+			useitem()
+			return 0
 		elif (cur_button == 3):
 			useskill()
 			return
