@@ -328,12 +328,14 @@ class shop_item:
 		self.power = 0
 		self.description = ""
 		self.actions = []
+		self.picture = ""
 		#if adding an actual item, initialize to the item's qualities.
 		if (itemnum != -1):
 			self.cost = g.item.item[itemnum].price
 			self.buytype = "gold"
 			self.power = g.item.item[itemnum].quality
 			self.description = g.item.item[itemnum].description
+			self.picture = g.item.item[itemnum].picturename
 
 	def add_cost(self, itemcost):
 		self.cost = itemcost
@@ -345,6 +347,8 @@ class shop_item:
 		self.description = itemdescription
 	def add_act(self, action):
 		self.actions.append(action)
+	def add_picture(self, picture):
+		self.picture = picture
 
 class shop:
 	def __init__(self, shopname):
@@ -365,6 +369,8 @@ class shop:
 		self.itemlist[self.curitem].add_description(itemdescription)
 	def item_add_act(self, action):
 		self.itemlist[self.curitem].add_act(action)
+	def item_add_picture(self, picture):
+		self.itemlist[self.curitem].add_picture(picture)
 
 shops = []
 
@@ -403,6 +409,8 @@ def read_shops():
 				shops[cur_shop].item_add_buytype(command[1].strip().lower())
 			elif (command[0].strip().lower() == "power"):
 				shops[cur_shop].item_add_power(command[1].strip().lower())
+			elif (command[0].strip().lower() == "picture"):
+				shops[cur_shop].item_add_picture(command[1].strip().lower())
 			else:
 				shops[cur_shop].item_add_act(shop_line)
 
