@@ -45,16 +45,20 @@ def refresh_inv():
 	#if the inv is selected, draw a selection box around the current item.
 	if curr_focus == 0:
 		canvas_inv.create_rectangle(
-				(curr_item%4)*g.tilesize + 2 * ((curr_item%4)+1),
-				(curr_item/4)*g.tilesize + 2 * ((curr_item/4)+1),
-				((curr_item%4)+1)*(g.tilesize + 2),
-				((curr_item/4)+1)*(g.tilesize + 2), fill="#A0A0ff", tags="item")
+				(curr_item%shop_width)*g.tilesize +
+							2 * ((curr_item%shop_width)+1),
+				(curr_item/shop_width)*g.tilesize +
+							2 * ((curr_item/shop_width)+1),
+				((curr_item%shop_width)+1)*(g.tilesize + 2),
+				((curr_item/shop_width)+1)*(g.tilesize + 2),
+							fill="#A0A0ff", tags="item")
 
 	#draw the item pictures.
 	for i in range(len(item.inv)):
 		if item.inv[i] != -1:
-			canvas_inv.create_image((i%4)*g.tilesize + 2 * ((i%4)+1),
-				(i/4)*g.tilesize + 2 * ((i/4)+1),
+			canvas_inv.create_image((i%shop_width)*g.tilesize + 2 *
+												((i%shop_width)+1),
+				(i/shop_width)*g.tilesize + 2 * ((i/shop_width)+1),
 				image=g.tiles[item.item[item.inv[i]].picturename],
 				anchor="nw", tags="item")
 			invpos += 1
@@ -104,16 +108,20 @@ def refresh_shop():
 	#if the shop is selected, draw a selection box around the current item.
 	if curr_focus == 1:
 		canvas_shop.create_rectangle(
-				(curr_item%4)*g.tilesize + 2 * ((curr_item%4)+1),
-				(curr_item/4)*g.tilesize + 2 * ((curr_item/4)+1),
-				((curr_item%4)+1)*(g.tilesize + 2),
-				((curr_item/4)+1)*(g.tilesize + 2), fill="#A0A0ff", tags="item")
+				(curr_item%shop_width)*g.tilesize + 2 *
+												((curr_item%shop_width)+1),
+				(curr_item/shop_width)*g.tilesize + 2 *
+												((curr_item/shop_width)+1),
+				((curr_item%shop_width)+1)*(g.tilesize + 2),
+				((curr_item/shop_width)+1)*(g.tilesize + 2),
+												fill="#A0A0ff", tags="item")
 
 	#draw the item pictures.
 	for i in range(len(g.shops[store_num].itemlist)):
 		if i != -1:
-			canvas_shop.create_image((invpos%4)*g.tilesize + 2 * ((invpos%4)+1),
-				(invpos/4)*g.tilesize + 2 * ((invpos/4)+1),
+			canvas_shop.create_image((invpos%shop_width)*g.tilesize + 2 *
+													((invpos%shop_width)+1),
+				(invpos/shop_width)*g.tilesize + 2 * ((invpos/shop_width)+1),
 				image=g.tiles[g.shops[store_num].itemlist[i].picture],
 				anchor="nw", tags="item")
 			invpos += 1
